using System;
using System.Diagnostics;
using System.Threading;

namespace TestPooling {

	class TestProgram {
		static void Main(string[] args) {
			const string dsn = "uid = root; Host = localhost; Pooling = Yes";

			NullConnection[] conns = new NullConnection[1000];
			Random r = new Random();

			// Create a bunch of connections in one big pool.
			// Close a number of connections randomly.
			// Add a random delay between opening each connection.
			Trace.WriteLine(" - MAIN -   Creating " + conns.Length + " Connection objects...");
			for (int i = 0; i < conns.Length; i++) {
				Thread.Sleep(r.Next(0, 3));
				try {
					conns[i] = new NullConnection(dsn);
				} catch {
					Trace.WriteLine(" - MAIN -   Connection object could not open connection.");
				}
				if (conns[i] != null) {
					try {
						conns[i].Execute();
					} catch {
						Trace.WriteLine(" - MAIN -   Connection object could not execute query.");
					}
					if (r.Next(0, 2) == 1) {
						conns[i].Close();
						conns[i] = null;
					}
				}
			}
			Trace.WriteLine(" - MAIN -   Done creating Connection objects...");

			// At this point, in an optimal situation all the drivers
			// in the pool save a couple few are grabbed by the Connection
			// objects that are still active.  There should be very little
			// activity - a few pings et cetera from the free drivers in
			// the pool.

			// Sleep 2 minutes, then execute a command and release remaining connections.
			Thread.Sleep(120000);
			Trace.WriteLine(" - MAIN -   Closing remaining Connection objects...");
			for (int i = conns.Length - 1; i >= 0; i--) {
				if (conns[i] != null) {
					try {
						conns[i].Execute();
					} catch {
						Trace.WriteLine(" - MAIN -   Connection object could not execute query.");
					}
					conns[i].Close();
				}
			}

			// Avoid termination by the runtime when main thread exits.
			// The pool should tear down by itself now; you should see
			// all the sleeping threads slowly die away.
			Thread.Sleep(1000000);
		}
	}

}
